@@ -116,6 +116,9 @@ func loadList(cmd *cobra.Command) {
 	noTruncate, err := cmd.Flags().GetBool("no-truncate")
 	cmdutil.ExitIfError(err)
 
+	fixedColumns, err := cmd.Flags().GetUint("fixed-columns")
+	cmdutil.ExitIfError(err)
+
 	columns, err := cmd.Flags().GetString("columns")
 	cmdutil.ExitIfError(err)
 
@@ -128,9 +131,10 @@ func loadList(cmd *cobra.Command) {
 			loadList(cmd)
 		},
 		Display: view.DisplayFormat{
-			Plain:      plain,
-			NoHeaders:  noHeaders,
-			NoTruncate: noTruncate,
+			Plain:        plain,
+			NoHeaders:    noHeaders,
+			NoTruncate:   noTruncate,
+			FixedColumns: fixedColumns,
 			Columns: func() []string {
 				if columns != "" {
 					return strings.Split(columns, ",")
@@ -182,5 +186,6 @@ func SetFlags(cmd *cobra.Command) {
 	if cmd.HasParent() && cmd.Parent().Name() != "sprint" {
 		cmd.Flags().String("columns", "", "Comma separated list of columns to display in the plain mode.\n"+
 			fmt.Sprintf("Accepts: %s", strings.Join(view.ValidIssueColumns(), ", ")))
+		cmd.Flags().Uint("fixed-columns", 1, "Number of fixed columns in the interactive mode")
 	}
 }
