@@ -15,11 +15,12 @@ import (
 
 // DisplayFormat is a issue display type.
 type DisplayFormat struct {
-	Plain      bool
-	NoHeaders  bool
-	NoTruncate bool
-	Columns    []string
-	TableStyle tui.TableStyle
+	Plain        bool
+	NoHeaders    bool
+	NoTruncate   bool
+	Columns      []string
+	FixedColumns uint
+	TableStyle   tui.TableStyle
 }
 
 // IssueList is a list view for issues.
@@ -35,7 +36,7 @@ type IssueList struct {
 
 // Render renders the view.
 func (l *IssueList) Render() error {
-	if l.Display.Plain {
+	if tui.IsDumbTerminal() || l.Display.Plain {
 		w := tabwriter.NewWriter(os.Stdout, 0, tabWidth, 1, '\t', 0)
 		return l.renderPlain(w)
 	}
@@ -73,6 +74,7 @@ func (l *IssueList) Render() error {
 		tui.WithCopyFunc(copyURL(l.Server)),
 		tui.WithCopyKeyFunc(copyKey()),
 		tui.WithRefreshFunc(l.Refresh),
+		tui.WithFixedColumns(l.Display.FixedColumns),
 	)
 
 	return view.Paint(data)
@@ -145,7 +147,7 @@ func (l *IssueList) data() tui.TableData {
 	return data
 }
 
-func (IssueList) assignColumns(columns []string, issue *jira.Issue) []string {
+func (*IssueList) assignColumns(columns []string, issue *jira.Issue) []string {
 	var bucket []string
 
 	for _, column := range columns {
@@ -170,6 +172,8 @@ func (IssueList) assignColumns(columns []string, issue *jira.Issue) []string {
 			bucket = append(bucket, formatDateTime(issue.Fields.Created, jira.RFC3339))
 		case fieldUpdated:
 			bucket = append(bucket, formatDateTime(issue.Fields.Updated, jira.RFC3339))
+		case fieldLabels:
+			bucket = append(bucket, strings.Join(issue.Fields.Labels, ","))
 		}
 	}
 
