@@ -46,6 +46,7 @@ func (sl *SprintList) Render() error {
 		),
 		tui.WithInitialText(helpText),
 		tui.WithContentTableOpts(
+			tui.WithFixedColumns(sl.Display.FixedColumns),
 			tui.WithTableStyle(sl.Display.TableStyle),
 			tui.WithSelectedFunc(navigate(sl.Server)),
 			tui.WithViewModeFunc(func(r, c int, d interface{}) (func() interface{}, func(interface{}) (string, error)) {
@@ -75,13 +76,14 @@ func (sl *SprintList) Render() error {
 
 // RenderInTable renders the list in table view.
 func (sl *SprintList) RenderInTable() error {
-	if sl.Display.Plain {
+	if tui.IsDumbTerminal() || sl.Display.Plain {
 		w := tabwriter.NewWriter(os.Stdout, 0, tabWidth, 1, '\t', 0)
 		return sl.renderPlain(w)
 	}
 
 	data := sl.tableData()
 	view := tui.NewTable(
+		tui.WithFixedColumns(sl.Display.FixedColumns),
 		tui.WithTableStyle(sl.Display.TableStyle),
 		tui.WithTableFooterText(
 			fmt.Sprintf(
@@ -147,6 +149,7 @@ func (sl *SprintList) tabularize(issues []*jira.Issue) tui.TableData {
 			issue.Fields.Resolution.Name,
 			formatDateTime(issue.Fields.Created, jira.RFC3339),
 			formatDateTime(issue.Fields.Updated, jira.RFC3339),
+			strings.Join(issue.Fields.Labels, ","),
 		})
 	}
 
