@@ -408,3 +408,149 @@ func TestAddIssueComment(t *testing.T) {
 	err = client.AddIssueComment("TEST-1", "comment")
 	assert.Error(t, &ErrUnexpectedResponse{}, err)
 }
+
+func TestAddIssueWorklog(t *testing.T) {
+	var unexpectedStatusCode bool
+
+	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		assert.Equal(t, "POST", r.Method)
+		assert.Equal(t, "/rest/api/2/issue/TEST-1/worklog", r.URL.Path)
+		assert.Equal(t, "application/json", r.Header.Get("Accept"))
+		assert.Equal(t, "application/json", r.Header.Get("Content-Type"))
+
+		var (
+			expectedBody string
+			actualBody   = new(strings.Builder)
+		)
+
+		_, _ = io.Copy(actualBody, r.Body)
+
+		if strings.Contains(actualBody.String(), "started") {
+			expectedBody = `{"started":"2022-01-01T01:02:02.000+0200","timeSpent":"1h","comment":"comment"}`
+		} else {
+			expectedBody = `{"timeSpent":"1h","comment":"comment"}`
+		}
+
+		assert.Equal(t, expectedBody, actualBody.String())
+
+		if unexpectedStatusCode {
+			w.WriteHeader(400)
+		} else {
+			w.WriteHeader(201)
+		}
+	}))
+	defer server.Close()
+
+	client := NewClient(Config{Server: server.URL}, WithTimeout(3*time.Second))
+
+	err := client.AddIssueWorklog("TEST-1", "2022-01-01T01:02:02.000+0200", "1h", "comment")
+	assert.NoError(t, err)
+
+	err = client.AddIssueWorklog("TEST-1", "", "1h", "comment")
+	assert.NoError(t, err)
+
+	unexpectedStatusCode = true
+
+	err = client.AddIssueWorklog("TEST-1", "", "1h", "comment")
+	assert.Error(t, &ErrUnexpectedResponse{}, err)
+}
+
+func TestGetField(t *testing.T) {
+	var unexpectedStatusCode bool
+
+	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		assert.Equal(t, "/rest/api/2/field", r.URL.Path)
+
+		if unexpectedStatusCode {
+			w.WriteHeader(400)
+		} else {
+			resp, err := os.ReadFile("./testdata/fields.json")
+			assert.NoError(t, err)
+
+			w.Header().Set("Content-Type", "application/json")
+			w.WriteHeader(200)
+			_, _ = w.Write(resp)
+		}
+	}))
+	defer server.Close()
+
+	client := NewClient(Config{Server: server.URL}, WithTimeout(3*time.Second))
+
+	actual, err := client.GetField()
+	assert.NoError(t, err)
+
+	expected := []*Field{
+		{
+			ID:     "fixVersions",
+			Name:   "Fix Version/s",
+			Custom: false,
+			Schema: struct {
+				DataType string `json:"type"`
+				Items    string `json:"items,omitempty"`
+				FieldID  int    `json:"customId,omitempty"`
+			}{
+				DataType: "array",
+				Items:    "version",
+			},
+		},
+		{
+			ID:     "customfield_10111",
+			Name:   "Original story points",
+			Custom: true,
+			Schema: struct {
+				DataType string `json:"type"`
+				Items    string `json:"items,omitempty"`
+				FieldID  int    `json:"customId,omitempty"`
+			}{
+				DataType: "number",
+				FieldID:  10111,
+			},
+		},
+		{
+			ID:     "timespent",
+			Name:   "Time Spent",
+			Custom: false,
+			Schema: struct {
+				DataType string `json:"type"`
+				Items    string `json:"items,omitempty"`
+				FieldID  int    `json:"customId,omitempty"`
+			}{
+				DataType: "number",
+			},
+		},
+	}
+	assert.Equal(t, expected, actual)
+
+	unexpectedStatusCode = true
+
+	_, err = client.GetField()
+	assert.NotNil(t, err)
+}
+
+func TestRemoteLinkIssue(t *testing.T) {
+	var unexpectedStatusCode bool
+
+	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		assert.Equal(t, "/rest/api/2/issue/TEST-1/remotelink", r.URL.Path)
+		assert.Equal(t, http.MethodPost, r.Method)
+		assert.Equal(t, "application/json", r.Header.Get("Accept"))
+		assert.Equal(t, "application/json", r.Header.Get("Content-Type"))
+
+		if unexpectedStatusCode {
+			w.WriteHeader(400)
+		} else {
+			w.WriteHeader(201)
+		}
+	}))
+	defer server.Close()
+
+	client := NewClient(Config{Server: server.URL}, WithTimeout(3*time.Second))
+
+	err := client.RemoteLinkIssue("TEST-1", "weblink title", "http://weblink.com")
+	assert.NoError(t, err)
+
+	unexpectedStatusCode = true
+
+	err = client.RemoteLinkIssue("TEST-1", "weblink title", "https://weblink.com")
+	assert.Error(t, &ErrUnexpectedResponse{}, err)
+}
